#
# spec file for package pigz
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pigz
VCS: https://src.suse.de/SLFO-pool/pigz#55c7bd4ca09fb31977098827d0f3f34df3247bf3374c056ee76fa785beee4093
Version:        2.8
Release:        160000.1.11
Summary:        Multi-core gzip version
License:        Zlib
Group:          Productivity/Archiving/Compression
URL:            https://www.zlib.net/pigz/
Source0:        https://www.zlib.net/%{name}/%{name}-%{version}.tar.gz
Source1:        https://www.zlib.net/%{name}/%{name}-%{version}-sig.txt#/%{name}-%{version}.tar.gz.asc
Source9:        %{name}.keyring
BuildRequires:  zlib-devel

%description
A parallel implementation of gzip for modern multi-processor, multi-core machines

%prep
%autosetup -p1

%build
%make_build

%check
%make_build tests

%install
install -Dpm 0755 pigz \
  %{buildroot}%{_bindir}/pigz
install -Dpm 0644 pigz.1 \
  %{buildroot}%{_mandir}/man1/pigz.1
ln -sv pigz %{buildroot}%{_bindir}/unpigz

%files
%doc README
%{_bindir}/pigz
%{_bindir}/unpigz
%{_mandir}/man1/pigz.1%{?ext_man}

%changelog
* Mon Sep  4 2023 pgajdos@suse.com
- version update to 2.8
  - Fixed a version bug when compiling with the just-released zlib 1.3
  - Will save a modification time only for regular files (just like gzip since 1.10)
  - Will write all available uncompressed data on an error, for partial data recovery
- deleted patches
  - pigz-2.7-NOTHREAD-tests.patch (upstreamed)
* Sat May  7 2022 andreas.stieger@gmx.de
- update to 2.7:
  * Improved display of multiple-member gzip files
  * Better gzip compatibility and bug fixes
- add pigz-2.7-NOTHREAD-tests.patch to fix tests
* Sun Feb  7 2021 dmueller@suse.com
- update to 2.6:
  * Add --huffman/-H and --rle/U strategy options
  * Fix issue when compiling for no threads
  * Fail silently on a broken pipe
  * Add --alias/-A option to set .zip name for stdin input
  * Add --comment/-C option to add comment in .gz or .zip
  * Several bug and behavior fixes
- drop fortify.patch: obsolete
* Wed Aug 12 2020 crrodriguez@opensuse.org
- Build with -fexceptions to get compiler/os specific (aka. sane)
  implementations of pthread_cleanup* routines.
* Thu Jul 12 2018 mpluskal@suse.com
- Update to version 2.4:
  * Generate Zip64 format .zip files when the output is greater
    than or equal to 4 GiB.
  * Improved gzip options processing and return code compatibility
  * Some bug fixes
- Drop no longer needed patches:
  * pigz-fix-missing-linker.patch
  * pigz-fix-wrong-include.patch
* Wed Aug 16 2017 psychonaut@nothingisreal.com
- Update to 2.3.4:
  * no upstream changelog provided
* Wed Mar 11 2015 p.drouand@gmail.com
- Update to version 2.3.3
  * Portability improvements
  * Update copyright years in documentation
- Add build fix patches
  * pigz-fix-wrong-include.patch
  * pigz-fix-missing-linker.patch
- Remove pigz-lm.patch; fixed
- Use download Url as source
* Thu Mar 14 2013 adam@mizerski.pl
- update to 2.3
  * Don't complain about missing suffix when not writing output file
  * Put all global variables in one global structure for readability
  * Do not decompress concatenated zlib streams -- only gzip streams
  * Add option for compression level 11 to use zopfli
  * Fix handling of junk after compressed data
- added pigz-lm.patch
  * adds missing "-lm"
- provide unpigz binary and manpage as symlink, not copy.
- removed fake cc script - build system honors CC
- cleanup spec file
* Tue Nov 27 2012 sweet_f_a@gmx.de
- update to 2.2.5:
  * add --rsyncable functionality
  * many bug fixes
- remove all suse patches:
  * pigz-dictzip.patch, large and unmaintained patch. If somebody
    really needs that then we should rebase and test it. In this
    case --dictzip should be probably also added to original gzip.
  * pigz-always-thread.patch was a folloup of pigz-dictzip.patch
  * pigz-do-symlinks.patch added IMO dangerous and stupid behaviour
    for symlinks. The original behaviour is now again like we know
    it from gzip, bzip2 and xz.
  * pigz-spl.patch, why we hacked in special handling of .spl
    files?
  * Generally we want to have pigz to replace gzip (and vice versa)
    so better avoiding interface incompatibilities.
- cleanup spec file
* Fri Sep 30 2011 uli@suse.com
- cross-build workaround: use fake cc script to work around build
  system that does not honor CC
* Thu Jun  2 2011 visnov@suse.cz
- update to 2.1.6
- package unpigz
- create debug packages
- package manpage
* Mon Apr 19 2010 agraf@suse.de
- fix dictzip with #CPU == 1 (bnc#597756)
* Wed Mar  3 2010 visnov@suse.de
- include symlinks patch
* Tue Oct 20 2009 jmatejek@suse.de
- initial package
